GainMapPresence

Enum GainMapPresence 

#[non_exhaustive]
pub enum GainMapPresence { Unknown, Absent, Available(Box<GainMapInfo>), }
Gain map detection state during probe.

Three-state presence indicator:

  • Unknown — can’t determine from bytes probed (gain map may be beyond probe window)
  • Absent — definitively no gain map in this file
  • Available — gain map found and metadata parsed

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown

Cannot determine gain map presence from bytes probed so far.



Absent

File definitively has no gain map.



Available(Box<GainMapInfo>)

Gain map present, metadata parsed.

Implementations

Source

impl GainMapPresence

pub fn is_present(&self) -> bool

Whether a gain map is definitely present.

pub fn is_absent(&self) -> bool

Whether a gain map is definitively absent.

pub fn is_unknown(&self) -> bool

Whether gain map presence is unknown.

pub fn info(&self) -> Option<&GainMapInfo>

Reference to the gain map info, if available.

pub fn into_info(self) -> Option<Box<GainMapInfo>>

Consume and return the gain map info, if available.